﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using AreYouAHuman;
using BlogEngine.Core.Web.Extensions;
using WebGrease.Css.Extensions;

namespace App_Code.Controls
{
    /// <summary>
    /// Summary description for AreYouAHumanControl
    /// </summary>
    public class AreYouAHumanControl : WebControl, IValidator
    {
        private  readonly string _publisherKey;

        public AreYouAHumanControl()
        {
            var settings = ExtensionManager.GetSettings("AreYouAHuman");
            _publisherKey = settings.GetSingleValue("PublisherKey");
        }

        protected override void RenderContents(HtmlTextWriter writer)
        {
            var extension = ExtensionManager.GetExtension("AreYouAHuman");
            if (extension.Enabled)
            {
                var ayah = new AyahServiceIntegration();
                writer.Write(ayah.GetPublisherHtml(_publisherKey));

                writer.Write("<script type=\"text/javascript\">\r\n" +
                             "var ayahCompleted = false\r\n" +
                             "function ayahCompletedHandler(e)\r\n" +
                             "{\r\n" +
                             "    ayahCompleted = true\r\n" +
                             "}\r\n" +
                             "AYAH.addGameCompleteHandler(ayahCompletedHandler)\r\n" +
                             "function ValidateAyah(source, arguments)\r\n" +
                             "{\r\n" +
                             "    arguments.IsValid = ayahCompleted;\r\n" +
                             "}\r\n" +
                             "</script>");
            }
        }

        /// <summary>
        ///     Gets or sets Theme.
        /// </summary>
        public string Theme { get; set; }

        /// <summary>
        ///     Gets or sets Language.
        /// </summary>
        public string Language { get; set; }

        /// <summary>
        ///     Gets or sets UserUniqueIdentifier.
        /// </summary>
        public string UserUniqueIdentifier { get; set; }


        public string ErrorMessage
        {
            get
            {
                return "Complete the challenge";
            }
            set
            {
            }
        }

        public bool IsValid
        {
            get
            {
                return Controls.OfType<IValidator>().All(c => c.IsValid) && Page.IsValid;
            }
            set
            {
            }
        }

        public void Validate()
        {
            Controls.OfType<IValidator>().ForEach(v => Validate());
        }

        public bool ValidateAsync(string response, string challenge)
        {
            Validate();
            return IsValid;
        }

    }
}